Changelog
=========

v0.4.1
------
* create pure python packaging
* include wheel file
* package as python3 only
* fix flake8 warnings
* add pypi badge
* add new targets
* automate notebook checking

v0.5.0
------
* initial check-in
* basic functionality for Ronchi tests
* basic functionality for Foucault knife edge tests
